pub struct Insertion { /* private fields */ }Expand description
An insertion in CRDT coordinates.
This struct is created by the inserted method on the
Replica owned by the peer that performed the insertion, and can be
integrated by another Replica via the
integrate_insertion method.
See the documentation of those methods for more information.
Implementations