Type Alias cola::ProtocolVersion

source ·
pub type ProtocolVersion = u64;
The version of the protocol cola uses to represent EncodedReplicas and CrdtEdits.

You can think of this as a version number for cola’s internal representation of the subset of its data structures that are exchanged between peers.

If different peers are using versions of cola with the same protocol number they’re compatible. If not, decoding EncodedReplicas and deserializing CrdtEdits will fail.

Protocol stability

cola is still far away from reaching stability, and until that happens its internal ProtocolVersion might change very frequently. After the 1.0 release the protocol version will only be allowed to be incremented in major releases (if at all).