pub struct Anchor { /* private fields */ }Expand description
A stable reference to a position in a Replica.
After its creation, an Anchor can be given to a Replica to
retrieve the current offset of the position it refers to, taking into
account all the edits that have been applied to the Replica in the
meantime.
This property makes Anchors useful to implement things like cursors and
selections in collaborative editing environments.
For more information, see the documentation of
Replica::create_anchor() and
Replica::resolve_anchor().